@@ -1,6 +1,7 @@
 import numpy as np
 import os
-import warnings
+import inspect
+from ..utils.gsflow_io import _warning
 import flopy as fp
 
 try:
@@ -13,8 +14,6 @@ try:
 except ImportError:
     pycrs = None
 
-warnings.simplefilter("always", UserWarning)
-
 
 class Modsim(object):
     """
@@ -24,14 +23,15 @@ class Modsim(object):
 
     Parameters
     ----------
-        model : gsflow.GsflowModel instance or gsflow.modflow.Modflow instance
-        other : str or None
-            include can be used to add an optional sfr field (ex. strhc1) to the
-            stream vector shapefile.
+    model : gsflow.GsflowModel instance or gsflow.modflow.Modflow instance
+    other : str or None
+        include can be used to add an optional sfr field (ex. strhc1) to the
+        stream vector shapefile.
 
     Examples
     --------
 
+    >>> import gsflow
     >>> gsf = gsflow.GsflowModel.load_from_file("gsflow.control")
     >>> modsim = gsflow.modsim.Modsim(gsf)
     >>> modsim.write_modsim_shapefile("myshp.shp")
@@ -62,15 +62,12 @@ class Modsim(object):
             self._ready = False
 
         self._nearest = True
+        self._sfr_nearest = False
 
     @property
     def sfr_segs(self):
         """
-        Get all of the SFR segments
-
-        Returns
-        -------
-            list of sfr segments
+        Returns a list of the SFR segments
 
         """
         if not self._ready:
@@ -87,11 +84,7 @@ class Modsim(object):
     @property
     def lake_segs(self):
         """
-        Get all of the lake numbers connected to SFR segments
-
-        Returns
-        -------
-            list of all lakes in the sfr network
+        Returns a list of the lake numbers connected to SFR segments
 
         """
         if not self._ready:
@@ -114,29 +107,23 @@ class Modsim(object):
     @property
     def sfr_topology(self):
         """
-        Creates a list of SFR topology objects
-
-        Returns
-        -------
-            list of _SfrTopology objects for writing
-            to shapefile
+        Returns a list of SFR topology objects for writing to shapefile
 
         """
         sfr_topo = []
         for seg in self.sfr_segs:
-            sfr_topo.append(_SfrTopology(self._sfr, self.mf, seg, self._other))
+            sfr_topo.append(
+                _SfrTopology(
+                    self._sfr, self.mf, seg, self._sfr_nearest, self._other
+                )
+            )
 
         return sfr_topo
 
     @property
     def lake_topology(self):
         """
-        Creates a list of LAK topology objects
-
-        Returns
-        -------
-            list of _LakTopology objects for writing
-            to shapefile
+        Returns a list of LAK topology objects for writing to shapefile
 
         """
         lake_topo = []
@@ -213,20 +200,13 @@ class Modsim(object):
 
         return temp
 
-    def __add_field(self, field_name):
-        """
-
-        Parameters
-        ----------
-        field_name
-
-        Returns
-        -------
-
-        """
-
     def write_modsim_shapefile(
-        self, shp=None, proj4=None, flag_spillway=False, nearest=True
+        self,
+        shp=None,
+        proj4=None,
+        flag_spillway=False,
+        nearest=True,
+        sfr_nearest=False,
     ):
         """
         Method to create a modsim compatible
@@ -258,14 +238,18 @@ class Modsim(object):
             SFR reaches based on the segment they are connected to. If False
             lak topology will connect to the start or end of the Segment based
             on iupseg and outseg
+        sfr_nearest : bool
+            if sfr_nearest is True, sfr topology will connect using the
+            distance equation. If False topology will connect to the start
+            or end of the Segment based on iupseg and outseg
 
         """
         if not self._ready:
             return
 
         if shapefile is None:
-            warn = "Pyshp must be installed to write MODSIM shapefile"
-            warnings.warn(warn)
+            msg = "Pyshp must be installed to write MODSIM shapefile"
+            _warning(msg, inspect.getframeinfo(inspect.currentframe()))
             return
 
         if shp is None:
@@ -276,6 +260,7 @@ class Modsim(object):
             shp = os.path.join(ws, name)
 
         self._nearest = nearest
+        self._sfr_nearest = sfr_nearest
 
         sfr_topology = self.sfr_topology
         lake_topology = self.lake_topology
@@ -337,11 +322,11 @@ class Modsim(object):
             pass
 
         if pycrs is None:
-            warn = (
+            msg = (
                 "PyCRS must be installed to add a projection"
                 " to {}".format(shp)
             )
-            warnings.warn(warn)
+            _warning(msg, inspect.getframeinfo(inspect.currentframe()))
             return
 
         t = shp.split(".")
@@ -368,11 +353,11 @@ class Modsim(object):
                 crs = None
 
         if crs is None:
-            warn = (
-                "Please provide a valid proj4 or epsg code to "
-                "flopy's model grid: Skipping writing {}".format(prj)
+            msg = (
+                "Please provide a valid proj4 or epsg code to flopy's"
+                f"model grid: Skipping writing {os.path.split(prj)[-1]}"
             )
-            warnings.warn(warn)
+            _warning(msg, inspect.getframeinfo(inspect.currentframe()))
             return
 
         with open(prj, "w") as foo:
@@ -589,6 +574,9 @@ class _SfrTopology(object):
     model : flopy.modflow.Modflow or gsflow.modflow.Modflow object
     iseg : int
         sfr segment number
+    nearest : bool
+        method to determine whether topology is calculated via distance eq.
+        default is False
     other : str or None
         include can be used to add an optional sfr field (ex. strhc1) to the
         stream vector shapefile.
@@ -596,11 +584,12 @@ class _SfrTopology(object):
 
     """
 
-    def __init__(self, sfr, model, iseg, other=None):
+    def __init__(self, sfr, model, iseg, nearest=False, other=None):
         self._sfr = sfr
         self._parent = model
         self._iseg = iseg
         self._other = other
+        self._nearest = nearest
         self._mg = self._parent.modelgrid
         self._xv = self._mg.xvertices
         self._yv = self._mg.yvertices
@@ -653,31 +642,43 @@ class _SfrTopology(object):
 
         ijup = []
         ijout = []
+        irchup = []
+        irchout = []
         for rec in self._sfr.reach_data:
             if rec.iseg == iupseg:
                 ijup.append([rec.i, rec.j])
+                irchup.append(rec.ireach)
             elif rec.iseg == outseg:
                 ijout.append([rec.i, rec.j])
+                irchout.append(rec.ireach)
             else:
                 pass
 
-        updist = []
-        for i, j in ijup:
-            a = (i - self.ij[0]) ** 2
-            b = (j - self.ij[1]) ** 2
-            c = np.sqrt(a + b)
-            updist.append(c)
+        if self._nearest:
+            updist = []
+            for i, j in ijup:
+                a = (i - self.ij[0]) ** 2
+                b = (j - self.ij[1]) ** 2
+                c = np.sqrt(a + b)
+                updist.append(c)
 
-        outdist = []
-        for i, j in ijout:
-            a = (i - self.ij[0]) ** 2
-            b = (j - self.ij[1]) ** 2
-            c = np.sqrt(a + b)
-            outdist.append(c)
+            outdist = []
+            for i, j in ijout:
+                a = (i - self.ij[0]) ** 2
+                b = (j - self.ij[1]) ** 2
+                c = np.sqrt(a + b)
+                outdist.append(c)
+        else:
+            updist = irchup
+            outdist = irchout
 
         if updist:
-            upidx = updist.index(np.min(updist))
-            ijup = [ijup[upidx]]
+            if self._nearest:
+                upidx = updist.index(np.min(updist))
+                ijup = [ijup[upidx]]
+            else:
+                upidx = updist.index(np.max(updist))
+                ijup = [ijup[upidx]]
 
         if outdist:
             outix = outdist.index(np.min(outdist))
